@@ -5,8 +5,12 @@
 use ruma_serde::StringEnum;
 
 /// A description of a user's connectivity and availability for chat.
+///
+/// This type can hold an arbitrary string. To check for formats that are not available as a
+/// documented variant here, use its string representation, obtained through `.as_str()`.
 #[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
 #[ruma_enum(rename_all = "snake_case")]
+#[non_exhaustive]
 pub enum PresenceState {
     /// Disconnected from the service.
     Offline,
@@ -32,3 +36,10 @@ impl Default for &'_ PresenceState {
         &PresenceState::Online
     }
 }
+
+impl PresenceState {
+    /// Creates a string slice from this `PresenceState`.
+    pub fn as_str(&self) -> &str {
+        self.as_ref()
+    }
+}
